==> ideaIC-15.0.3-sources.jar: com/intellij/execution/junit/JUnitProcessHandler.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.execution.junit;

import com.intellij.execution.ExecutionException;
import com.intellij.execution.configurations.GeneralCommandLine;
import com.intellij.execution.junit2.segments.Extractor;
import com.intellij.execution.process.KillableColoredProcessHandler;
import com.intellij.execution.process.ProcessAdapter;
import com.intellij.execution.process.ProcessEvent;
import com.intellij.execution.process.ProcessTerminatedListener;
import com.intellij.openapi.util.Disposer;
import org.jetbrains.annotations.NotNull;

import java.io.Reader;

/**
 * @author dyoma
 */
public class JUnitProcessHandler extends KillableColoredProcessHandler {
  private final Extractor myOut;
  private final Extractor myErr;

  private JUnitProcessHandler(@NotNull GeneralCommandLine commandLine) throws ExecutionException {
    super(commandLine);

    myOut = new Extractor(getProcess().getInputStream(), commandLine.getCharset());
    myErr = new Extractor(getProcess().getErrorStream(), commandLine.getCharset());
    addProcessListener(new ProcessAdapter(){
      @Override
      public void processTerminated(ProcessEvent event) {
        Disposer.dispose(myOut);
        Disposer.dispose(myErr);
      }
    });
  }

  @Override
  protected Reader createProcessOutReader() {
    return myOut.createReader();
  }

  @Override
  protected Reader createProcessErrReader() {
    return myErr.createReader();
  }

  @NotNull
  public Extractor getErr() {
    return myErr;
  }

  @NotNull
  public Extractor getOut() {
    return myOut;
  }

  @NotNull
  public static JUnitProcessHandler runCommandLine(@NotNull GeneralCommandLine commandLine) throws ExecutionException {
    final JUnitProcessHandler processHandler = new JUnitProcessHandler(commandLine);
    ProcessTerminatedListener.attach(processHandler);
    return processHandler;
  }

  @Override
  protected boolean useNonBlockingRead() {
    return true;
  }
}

==> ideaIC-141.1192.2-sources.jar: com/intellij/execution/junit/JUnitProcessHandler.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.execution.junit;

import com.intellij.execution.ExecutionException;
import com.intellij.execution.configurations.GeneralCommandLine;
import com.intellij.execution.junit2.segments.Extractor;
import com.intellij.execution.process.KillableColoredProcessHandler;
import com.intellij.execution.process.ProcessTerminatedListener;
import org.jetbrains.annotations.NotNull;

import java.io.Reader;

/**
 * @author dyoma
 */
public class JUnitProcessHandler extends KillableColoredProcessHandler {
  private final Extractor myOut;
  private final Extractor myErr;

  public JUnitProcessHandler(@NotNull GeneralCommandLine commandLine) throws ExecutionException {
    super(commandLine);

    myOut = new Extractor(getProcess().getInputStream(), commandLine.getCharset());
    myErr = new Extractor(getProcess().getErrorStream(), commandLine.getCharset());
  }

  @Override
  protected Reader createProcessOutReader() {
    return myOut.createReader();
  }

  @Override
  protected Reader createProcessErrReader() {
    return myErr.createReader();
  }

  @NotNull
  public Extractor getErr() {
    return myErr;
  }

  @NotNull
  public Extractor getOut() {
    return myOut;
  }

  @NotNull
  public static JUnitProcessHandler runCommandLine(@NotNull GeneralCommandLine commandLine) throws ExecutionException {
    final JUnitProcessHandler processHandler = new JUnitProcessHandler(commandLine);
    ProcessTerminatedListener.attach(processHandler);
    return processHandler;
  }
}
